==> duckdb_0.7.1-1.tar.gz: duckdb/src/duckdb/ub_src_planner_operator.cpp <==
#include "src/planner/operator/logical_aggregate.cpp"

#include "src/planner/operator/logical_any_join.cpp"

#include "src/planner/operator/logical_column_data_get.cpp"

#include "src/planner/operator/logical_comparison_join.cpp"

#include "src/planner/operator/logical_copy_to_file.cpp"

#include "src/planner/operator/logical_create.cpp"

#include "src/planner/operator/logical_create_index.cpp"

#include "src/planner/operator/logical_create_table.cpp"

#include "src/planner/operator/logical_cross_product.cpp"

#include "src/planner/operator/logical_cteref.cpp"

#include "src/planner/operator/logical_delete.cpp"

#include "src/planner/operator/logical_delim_get.cpp"

#include "src/planner/operator/logical_delim_join.cpp"

#include "src/planner/operator/logical_distinct.cpp"

#include "src/planner/operator/logical_dummy_scan.cpp"

#include "src/planner/operator/logical_empty_result.cpp"

#include "src/planner/operator/logical_execute.cpp"

#include "src/planner/operator/logical_explain.cpp"

#include "src/planner/operator/logical_export.cpp"

#include "src/planner/operator/logical_expression_get.cpp"

#include "src/planner/operator/logical_extension_operator.cpp"

#include "src/planner/operator/logical_filter.cpp"

#include "src/planner/operator/logical_get.cpp"

#include "src/planner/operator/logical_insert.cpp"

#include "src/planner/operator/logical_join.cpp"

#include "src/planner/operator/logical_limit.cpp"

#include "src/planner/operator/logical_limit_percent.cpp"

#include "src/planner/operator/logical_order.cpp"

#include "src/planner/operator/logical_positional_join.cpp"

#include "src/planner/operator/logical_pragma.cpp"

#include "src/planner/operator/logical_prepare.cpp"

#include "src/planner/operator/logical_projection.cpp"

#include "src/planner/operator/logical_recursive_cte.cpp"

#include "src/planner/operator/logical_sample.cpp"

#include "src/planner/operator/logical_set.cpp"

#include "src/planner/operator/logical_reset.cpp"

#include "src/planner/operator/logical_set_operation.cpp"

#include "src/planner/operator/logical_show.cpp"

#include "src/planner/operator/logical_simple.cpp"

#include "src/planner/operator/logical_top_n.cpp"

#include "src/planner/operator/logical_unconditional_join.cpp"

#include "src/planner/operator/logical_unnest.cpp"

#include "src/planner/operator/logical_update.cpp"

#include "src/planner/operator/logical_window.cpp"

==> duckdb_0.9.1.tar.gz: duckdb/src/duckdb/ub_src_planner_operator.cpp <==
#include "src/planner/operator/logical_aggregate.cpp"

#include "src/planner/operator/logical_any_join.cpp"

#include "src/planner/operator/logical_column_data_get.cpp"

#include "src/planner/operator/logical_comparison_join.cpp"

#include "src/planner/operator/logical_copy_to_file.cpp"

#include "src/planner/operator/logical_create.cpp"

#include "src/planner/operator/logical_create_index.cpp"

#include "src/planner/operator/logical_create_table.cpp"

#include "src/planner/operator/logical_cross_product.cpp"

#include "src/planner/operator/logical_cteref.cpp"

#include "src/planner/operator/logical_delete.cpp"

#include "src/planner/operator/logical_delim_get.cpp"

#include "src/planner/operator/logical_dependent_join.cpp"

#include "src/planner/operator/logical_distinct.cpp"

#include "src/planner/operator/logical_dummy_scan.cpp"

#include "src/planner/operator/logical_empty_result.cpp"

#include "src/planner/operator/logical_expression_get.cpp"

#include "src/planner/operator/logical_extension_operator.cpp"

#include "src/planner/operator/logical_filter.cpp"

#include "src/planner/operator/logical_get.cpp"

#include "src/planner/operator/logical_insert.cpp"

#include "src/planner/operator/logical_join.cpp"

#include "src/planner/operator/logical_limit.cpp"

#include "src/planner/operator/logical_limit_percent.cpp"

#include "src/planner/operator/logical_order.cpp"

#include "src/planner/operator/logical_pivot.cpp"

#include "src/planner/operator/logical_positional_join.cpp"

#include "src/planner/operator/logical_pragma.cpp"

#include "src/planner/operator/logical_prepare.cpp"

#include "src/planner/operator/logical_projection.cpp"

#include "src/planner/operator/logical_recursive_cte.cpp"

#include "src/planner/operator/logical_materialized_cte.cpp"

#include "src/planner/operator/logical_sample.cpp"

#include "src/planner/operator/logical_set.cpp"

#include "src/planner/operator/logical_reset.cpp"

#include "src/planner/operator/logical_set_operation.cpp"

#include "src/planner/operator/logical_simple.cpp"

#include "src/planner/operator/logical_top_n.cpp"

#include "src/planner/operator/logical_unconditional_join.cpp"

#include "src/planner/operator/logical_unnest.cpp"

#include "src/planner/operator/logical_update.cpp"

#include "src/planner/operator/logical_window.cpp"
